/*
Name: 			Core Initializer
Written by: 	Spyropress Themes - (http://spyropress.com)
Version: 		1.0.0
*/

(function( $, window ) {

	"use strict";

	var Core = {

		initialized: false,

		initialize: function() {

			if (this.initialized) return;
			this.initialized = true;

			this.build();
		},

		build: function() {

			// Adds browser version on html class.
			$.browserSelector();
            
            // Adds window smooth scroll on chrome.
			if($("html").hasClass("chrome")) {
				$.smoothScroll();
			}

			// Nav Menu
			this.navMenu();

			// Animations
			this.animations();

			// Word Rotate
			this.wordRotate();

			// Tooltips
			$("a[rel=tooltip]").tooltip();

			// Owl Carousel
			this.owlCarousel();
            
            // Sort
			this.sort();

			// Toggle
			this.toggle();

			// Lightbox
			this.lightbox();

			// Parallax
			this.parallax();
            
            //  Share
            this.share();

		},
        
        share: function() {
            // social share popups
            $(".list-share a").click(function(e) {
                e.preventDefault();
                window.open(this.href, "", "height = 500, width = 500");
            });
        },

		navMenu: function() {
            
            
            // Anchors Position
			$("a[data-hash]").on("click", function(e) {

				e.preventDefault();
                
				var target = $(this).attr("href"),
					$this = $(this);
                
				if($(window).width() > 991) {
					$("html,body").animate({ scrollTop: $(target).offset().top - 35 }, 600, "easeOutQuad");
				} else {
					$("html,body").animate({ scrollTop: $(target).offset().top - 35 }, 600, "easeOutQuad");
				}

				return false;

			});
            
			// Submenu Check Visible Space
			$("#mainMenu li.dropdown-submenu").hover(function() {

				if($(window).width() < 767) return;

				var subMenu = $(this).find("ul.dropdown-menu");

				if(!subMenu.get(0)) return;

				var screenWidth = $(window).width(),
					subMenuOffset = subMenu.offset(),
					subMenuWidth = subMenu.width(),
					subMenuParentWidth = subMenu.parents("ul.dropdown-menu").width(),
					subMenuPosRight = subMenu.offset().left + subMenu.width();

				if(subMenuPosRight > screenWidth) {
					subMenu.css("margin-left", "-" + (subMenuParentWidth + subMenuWidth + 10) + "px");
				} else {
					subMenu.css("margin-left", 0);
				}

			});

			// Mobile Redirect
			$(".mobile-redirect").on("click", function() {
				if($(window).width() < 991) {
					self.location = $(this).attr("href");
				}
			});
            
            // Doc Nav            
            $(document.body).scrollspy({
                target: ".documentation-nav",
                offset: 50
            });
            $('.documentation-nav').niceScroll({
                railoffset: {
                    top:10,
                    left:-10
                }
            });
            
		},

		stickyMenu: function() {

			if($("body").hasClass("boxed"))
				return false;

			var $this = this,
				$body = $("body"),
				header = $("#header"),
				headerHeight = parseInt( header.attr("data-sticky-offset") ? header.attr("data-sticky-offset") : 500 ),
                docNav = $('.documentation-nav'),
				logoWrapper = header.find(".logo"),
				logo = header.find(".logo img"),
				logoWidth = logo.attr("width"),
				logoHeight = logo.attr("height"),
				logoPaddingTop = parseInt(logo.attr("data-sticky-padding") ? logo.attr("data-sticky-padding") : "28"),
				logoSmallWidth = parseInt(logo.attr("data-sticky-width") ? logo.attr("data-sticky-width") : "82"),
				logoSmallHeight = parseInt(logo.attr("data-sticky-height") ? logo.attr("data-sticky-height") : "40");

			$this.checkStickyMenu = function() {

				if($body.hasClass("boxed") || $(window).width() < 991) {
					$this.stickyMenuDeactivate();
					header.removeClass("fixed");
                    
                    if( $(window).scrollTop() > headerHeight ) {
                        docNav.addClass("doc-sm-nav-sticky-active");
                    }
                    else {
                        docNav.removeClass("doc-sm-nav-sticky-active");
                    }
					return false;
				}

				if( $(window).scrollTop() > headerHeight ) {

					$this.stickyMenuActivate();
				} else {

					$this.stickyMenuDeactivate();

				}
			}

			$this.stickyMenuActivate = function() {

				if($body.hasClass("sticky-menu-active"))
					return false;

				logo.stop(true, true);
                header.stop(true, true);

				$body.addClass("sticky-menu-active");

				logoWrapper.addClass("logo-sticky-active");
                
                docNav.addClass("doc-nav-sticky-active");
                $('.documentation-nav').getNiceScroll().remove();

                header.animate({
                    top: '0px'
                }, 200, function() {});

				logo.animate({
					width: logoSmallWidth,
					height: logoSmallHeight,
					top: logoPaddingTop + "px"
				}, 200, function() {});

			}

			$this.stickyMenuDeactivate = function() {

				if($body.hasClass("sticky-menu-active")) {

					logoWrapper.removeClass("logo-sticky-active");
                    
                    docNav.removeClass("doc-nav-sticky-active");
                    $('.documentation-nav').niceScroll({
                        railoffset: {
                            top:10,
                            left:-10
                        }
                    });
                    
                    logo.stop(true, true);
                    header.stop(true, true);
                
                    header.animate({
                        top: '-80px'
                    }, 200, function(){
                        $body.removeClass("sticky-menu-active");
                        header.removeAttr('style')
                    });

					logo.animate({
						width: logoWidth,
						height: logoHeight,
						top: "0px"
					}, 200);

				}
			}


			$(window).on("scroll", function() {

				$this.checkStickyMenu();

			});

			$this.checkStickyMenu();

		},

		animations: function() {

			// Animation Appear
			$("[data-appear-animation]").each(function() {

				var $this = $(this);

				$this.addClass("appear-animation");

				if(!$("html").hasClass("no-csstransitions") && $(window).width() > 767) {

					$this.appear(function() {

						var delay = ($this.attr("data-appear-animation-delay") ? $this.attr("data-appear-animation-delay") : 1);

						if(delay > 1) $this.css("animation-delay", delay + "ms");
						$this.addClass($this.attr("data-appear-animation"));

						setTimeout(function() {
							$this.addClass("appear-animation-visible");
						}, delay);

					}, {accX: 0, accY: -150});

				} else {

					$this.addClass("appear-animation-visible");

				}

			});

			// Animation Progress Bars
			$("[data-appear-progress-animation]").each(function() {

				var $this = $(this);

				$this.appear(function() {

					var delay = ($this.attr("data-appear-animation-delay") ? $this.attr("data-appear-animation-delay") : 1);

					if(delay > 1) $this.css("animation-delay", delay + "ms");
					$this.addClass($this.attr("data-appear-animation"));

					setTimeout(function() {

						$this.animate({
							width: $this.attr("data-appear-progress-animation")
						}, 1500, "easeOutQuad", function() {
							$this.find(".progress-bar-tooltip").animate({
								opacity: 1
							}, 500, "easeOutQuad");
						});

					}, delay);

				}, {accX: 0, accY: -50});

			});

			// Count To
			$(".counters [data-to]").each(function() {

				var $this = $(this);

				$this.appear(function() {

					$this.countTo({
						onComplete: function() {
							if($this.data("append")) {
								$this.html($this.html() + $this.data("append"));
							}
						}
					});

				}, {accX: 0, accY: -150});

			});
		},

		wordRotate: function() {

            $(".word-rotate").each(function() {

				var $this = $(this),
					itemsWrapper = $this.find(".word-rotate-items"),
					items = itemsWrapper.find("> span"),
					firstItem = items.eq(0),
					firstItemClone = firstItem.clone(),
					itemHeight = 0,
					currentItem = 1,
					currentTop = 0;

				itemHeight = firstItem.height();

				itemsWrapper.append(firstItemClone);

				$this
					.height(itemHeight)
					.addClass("active");

				setInterval(function() {

					currentTop = (currentItem * itemHeight);

					itemsWrapper.animate({
						top: -(currentTop) + "px"
					}, 300, "easeOutQuad", function() {

						currentItem++;

						if(currentItem > items.length) {

							itemsWrapper.css("top", 0);
							currentItem = 1;

						}

					});

				}, 2000);

			});

		},
		owlCarousel: function(options) {

			var total = $("div.owl-carousel:not(.manual)").length,
				count = 0;

			$("div.owl-carousel:not(.manual)").each(function() {

				var slider = $(this);

				var defaults = {
					 // Most important owl features
					itemsDesktopSmall : [980,3],
					singleItem : true,
                    
					// Navigation
					navigationText : ["<i class=\"fa fa-chevron-left\"></i>","<i class=\"fa fa-chevron-right\"></i>"]
				}

				var config = $.extend({}, defaults, options, slider.data("plugin-options"));

				// Initialize Slider
				slider.owlCarousel(config).addClass("owl-carousel-init");

			});

		},
        
        sort: function() {

			$("ul.sort-source:not(.manual)").each(function() {

				var source = $(this);
				var destination = $("ul.sort-destination[data-sort-id=" + $(this).attr("data-sort-id") + "]");

				if(destination.get(0)) {

					var minParagraphHeight = 0;
					var paragraphs = $("span.thumb-info-caption p", destination);

					paragraphs.each(function() {
						if($(this).height() > minParagraphHeight)
							minParagraphHeight = ($(this).height() + 10);
					});

					paragraphs.height(minParagraphHeight);

					$(window).load(function() {

						destination.isotope({
							itemSelector: "li",
							layoutMode: 'sloppyMasonry'
						});

						source.find("a").click(function(e) {

							e.preventDefault();

							var $this = $(this),
								filter = $this.parent().attr("data-option-value");

							source.find("a.label").removeClass("label label-warning");
							$this.addClass("label label-warning");

							destination.isotope({
								filter: filter
							});
                            
                            if(window.location.hash != "" || filter.replace(".","") != "*") {
								window.location.hash = filter.replace(".","");
							}

							return false;

						});
                        
                        $(window).bind("hashchange", function(e) {

							var hashFilter = "." + location.hash.replace("#",""),
								hash = (hashFilter == "." || hashFilter == ".*" ? "*" : hashFilter);

							source.find("li.active").removeClass("active");
							source.find("li[data-option-value='" + hash + "']").addClass("active");

							destination.isotope({
								filter: hash
							});

						});

						var hashFilter = "." + (location.hash.replace("#","") || "*");

						var initFilterEl = source.find("li[data-option-value='" + hashFilter + "'] a");

						if(initFilterEl.get(0)) {
							source.find("li[data-option-value='" + hashFilter + "'] a").click();
						} else {
							source.find("li:first-child a").click();
						}       
					});
				}
			});

		},
        
		toggle: function() {

			var $this = this,
				previewParClosedHeight = 25;

			$("section.toggle > label").prepend($("<i />").addClass("icon icon-plus"));
			$("section.toggle > label").prepend($("<i />").addClass("icon icon-minus"));
			$("section.toggle.active > p").addClass("preview-active");
			$("section.toggle.active > div.toggle-content").slideDown(350, function() {});

			$("section.toggle > label").click(function(e) {

				var parentSection = $(this).parent(),
					parentWrapper = $(this).parents("div.toogle"),
					previewPar = false,
					isAccordion = parentWrapper.hasClass("toogle-accordion");

				if(isAccordion && typeof(e.originalEvent) != "undefined") {
					parentWrapper.find("section.toggle.active > label").trigger("click");
				}

				parentSection.toggleClass("active");

				// Preview Paragraph
				if(parentSection.find("> p").get(0)) {

					previewPar = parentSection.find("> p");
					var previewParCurrentHeight = previewPar.css("height");
					previewPar.css("height", "auto");
					var previewParAnimateHeight = previewPar.css("height");
					previewPar.css("height", previewParCurrentHeight);

				}

				// Content
				var toggleContent = parentSection.find("> div.toggle-content");

				if(parentSection.hasClass("active")) {

					$(previewPar).animate({
						height: previewParAnimateHeight
					}, 350, function() {
						$(this).addClass("preview-active");
					});

					toggleContent.slideDown(350, function() {});

				} else {

					$(previewPar).animate({
						height: previewParClosedHeight
					}, 350, function() {
						$(this).removeClass("preview-active");
					});

					toggleContent.slideUp(350, function() {});

				}

			});

		},

		lightbox: function(options) {

			if(typeof($.magnificPopup) == "undefined") {
				return false;
			}

			// Internationalization of Lightbox
			$.extend(true, $.magnificPopup.defaults, {
				tClose: 'Close (Esc)', // Alt text on close button
				tLoading: 'Loading...', // Text that is displayed during loading. Can contain %curr% and %total% keys
				gallery: {
					tPrev: 'Previous (Left arrow key)', // Alt text on left arrow
					tNext: 'Next (Right arrow key)', // Alt text on right arrow
					tCounter: '%curr% of %total%' // Markup for "1 of 7" counter
				},
				image: {
					tError: '<a href="%url%">The image</a> could not be loaded.' // Error message when image could not be loaded
				},
				ajax: {
					tError: '<a href="%url%">The content</a> could not be loaded.' // Error message when ajax request failed
				}
			});

			$(".lightbox:not(.manual)").each(function() {

				var el = $(this);

				var config, defaults = {}
				if(el.data("plugin-options"))
					config = $.extend({}, defaults, options, el.data("plugin-options"));

				$(this).magnificPopup(config);

			});

		},

		parallax: function() {

			if(typeof($.stellar) == "undefined") {
				return false;
			}

			$(window).load(function () {

				if($(".parallax").get(0)) {
					if(!Modernizr.touch) {
						$(window).stellar({
							responsive:true,
							scrollProperty: 'scroll',
							parallaxElements: false,
							horizontalScrolling: false,
							horizontalOffset: 0,
							verticalOffset: 0
						});
					} else {
						$(".parallax").addClass("disabled");
					}
				}
			});

		}
	};

	Core.initialize();

	$(window).load(function () {

		// Sticky Meny
		Core.stickyMenu();
        
        $(document.body).scrollspy( "refresh" );

		// Window Resize
		$(window).afterResize(function() {

			// Sticky Menu
			if(typeof(Core.checkStickyMenu) != "undefined") {
				Core.checkStickyMenu();
			}
            
            // Isotope
			if($(".isotope").get(0)) {
				$(".isotope").isotope('reLayout');
			}

		}, true, 100 );

	});

})( jQuery, window );